Contributing
************

Contributions are welcome! Ocelot is true open source software - our code and development process is as open as we can make it.

You don't have to be a hardcore coder to make contributions - ideas for system models or specific tests are also welcome on the `system model variations wiki page <https://github.com/OcelotProject/Ocelot/wiki/System-model-variations>`__.

To contribute code, please follow the standard `Github workflow <https://guides.github.com/introduction/flow/>`__. Make sure to test any new transformation functions, and add yourself to the authors list on this page.

Authors
=======

The core Ocelot team is Chris Mutel from PSI and Guillaume Bourgault from ecoinvent.
